% Force_calculation_11
% Created 02/10/2015 from Potential_for_Simulation_CellShape_spindle_3D_ascidians13
% Calculates the net force and torque for a given [x y z theta phi] position of the nucleus
% MT force : F = L^Beta1 + pullfactor*L^Beta2 + pullfactor_exp*2^(L/Unit_branch) when touching polarity
% In paper : F = A L^3 + B [.] L^2 + C [.] 2^(L/a)


if ~ismember([x,y,z,theta,phi],CoordsPotentiel,'rows');  % skips calculation for an alredy explored position


    %% Initialisation parameters

    it=it+1;  % iteration

    % coordinates
    CoordsPotentiel(it,1)=x;
    CoordsPotentiel(it,2)=y;
    CoordsPotentiel(it,3)=z;
    CoordsPotentiel(it,4)=theta;
    CoordsPotentiel(it,5)=phi;

    % centrosomes coordinates
    thetarad=pi/(180)*(theta);
    phirad=pi/(180)*(phi);
    absCentro1=x+ Nucsize/2*sin(thetarad)*cos(phirad);
    ordCentro1=y+ Nucsize/2*sin(thetarad)*sin(phirad);
    altCentro1=z+ Nucsize/2*cos(thetarad);
    absCentro2=x- Nucsize/2*sin(thetarad)*cos(phirad);
    ordCentro2=y- Nucsize/2*sin(thetarad)*sin(phirad);
    altCentro2=z- Nucsize/2*cos(thetarad);

    % preallocations
    Abscfromcentro1=NaN(360,180);
    Ordofromcentro1=NaN(360,180);
    Altifromcentro1= NaN(360,180);
    Abscfromcentro2= NaN(360,180);
    Ordofromcentro2= NaN(360,180);
    Altifromcentro2= NaN(360,180);
    Xtot1= NaN(360,180);
    Ytot1= NaN(360,180);
    Ztot1= NaN(360,180);
    Xtot2= NaN(360,180);
    Ytot2= NaN(360,180);
    Ztot2= NaN(360,180);
    maxforpix= NaN(360,180);
    minforpix= NaN(360,180);
    r01= NaN(360,180);
    r02= NaN(360,180);
    y01= NaN(360,180);
    y02= NaN(360,180);
    p01= NaN(360,180);
    p02= NaN(360,180);
    Alphamat=bsxfun(@times,ones(360,180),1:180).*pi./(180);
    Psimat=bsxfun(@times,ones(360,180),(1:360)').*pi./(180);

    % trace too long MTs for each angle (to set directions)
    Abscfromcentro1(:,:)= absCentro1+ Diststart*(cos(Alphamat).*sin(thetarad).*cos(phirad)+sin(Alphamat).*cos(Psimat).*cos(phirad).*cos(thetarad)-sin(Alphamat).*sin(Psimat).*sin(phirad));
    Ordofromcentro1(:,:)= ordCentro1+ Diststart*(cos(Alphamat).*sin(thetarad).*sin(phirad)+sin(Alphamat).*cos(Psimat).*sin(phirad).*cos(thetarad)+sin(Alphamat).*sin(Psimat).*cos(phirad));
    Altifromcentro1(:,:)= altCentro1+ Diststart*(cos(Alphamat).*cos(thetarad)-sin(Alphamat).*cos(Psimat).*sin(thetarad));
    Abscfromcentro2(:,:)= absCentro2- Diststart*(cos(Alphamat).*sin(thetarad).*cos(phirad)+sin(Alphamat).*cos(Psimat).*cos(phirad).*cos(thetarad)-sin(Alphamat).*sin(Psimat).*sin(phirad));
    Ordofromcentro2(:,:)= ordCentro2- Diststart*(cos(Alphamat).*sin(thetarad).*sin(phirad)+sin(Alphamat).*cos(Psimat).*sin(phirad).*cos(thetarad)+sin(Alphamat).*sin(Psimat).*cos(phirad));
    Altifromcentro2(:,:)= altCentro2- Diststart*(cos(Alphamat).*cos(thetarad)-sin(Alphamat).*cos(Psimat).*sin(thetarad));

    % lengths of those MTs in micrometers
    Xtot1(:,:)=(Abscfromcentro1(:,:)-absCentro1);
    Ytot1(:,:)=(Ordofromcentro1(:,:)-ordCentro1);
    Ztot1(:,:)=(Altifromcentro1(:,:)-altCentro1);
    Xtot2(:,:)=(Abscfromcentro2(:,:)-absCentro2);
    Ytot2(:,:)=(Ordofromcentro2(:,:)-ordCentro2);
    Ztot2(:,:)=(Altifromcentro2(:,:)-altCentro2);
    maxforpix(:,:)=max(abs(Xtot1(:,:)),max(abs(Ytot1(:,:)),abs(Ztot1(:,:))));
    minforpix(:,:)=-max(abs(Xtot2),max(abs(Ytot2),abs(Ztot2)));
    maxforpix((maxforpix==0))=NaN;
    minforpix((minforpix==0))=NaN;


    %% for every angle in the aster, calculation of MT length and amount of yolk and polarity reached

    
    for alpha=1:floor(anglelimit*180)
        for psi=1:360

            % for 1st aster...
            valr1=zeros(ceil(maxforpix(psi,alpha)),2);          % line of zeros that will be filled with ones up to the cortex intersection
            valy1=zeros(ceil(maxforpix(psi,alpha)),4);          % line of zeros that will be filled with corresponding yolk levels up to the cortex intersection
            r=1:maxforpix(psi,alpha);                           % iteration along the MT length
            bornes=[find(floor(absCentro1+Xtot1(psi,alpha)*r/ maxforpix(psi,alpha))>size(Asub,1),1),find(floor(ordCentro1+Ytot1(psi,alpha)*r/ maxforpix(psi,alpha))>size(Asub,2),1),find( floor((altCentro1+Ztot1(psi,alpha)*r/ maxforpix(psi,alpha)-z)+z)>size(Asub,3),1),find(floor(absCentro1+Xtot1(psi,alpha)*r/ maxforpix(psi,alpha))<1,1),find(floor(ordCentro1+Ytot1(psi,alpha)*r/ maxforpix(psi,alpha))<1,1),find( floor((altCentro1+Ztot1(psi,alpha)*r/ maxforpix(psi,alpha)-z)+z)<1,1)];
            valy1(:,4)=((1:ceil(maxforpix(psi,alpha))).^3)';
            for r=1:min(maxforpix(psi,alpha),min(bornes)-1);  % Length calculation : iterative search (along the too long MT) for the intersecion with cortex
                valr1(r,1)=Asub(floor(absCentro1+Xtot1(psi,alpha)*r/ maxforpix(psi,alpha)),floor(ordCentro1+Ytot1(psi,alpha)*r/ maxforpix(psi,alpha)),floor((altCentro1+Ztot1(psi,alpha)*r/ maxforpix(psi,alpha)-z)+z));
                valy1(r,1)=Csub2(floor(absCentro1+Xtot1(psi,alpha)*r/ maxforpix(psi,alpha)),floor(ordCentro1+Ytot1(psi,alpha)*r/ maxforpix(psi,alpha)),floor((altCentro1+Ztot1(psi,alpha)*r/ maxforpix(psi,alpha)-z)+z));
                if size(Asub,1)>=ceil(absCentro1+Xtot1(psi,alpha)*r/ maxforpix(psi,alpha)) && size(Asub,2)>=ceil(ordCentro1+Ytot1(psi,alpha)*r/ maxforpix(psi,alpha)) && size(Asub,3)>=ceil((altCentro1+Ztot1(psi,alpha)*r/ maxforpix(psi,alpha)-z)+z)
                    valr1(r,2)=Asub(ceil(absCentro1+Xtot1(psi,alpha)*r/ maxforpix(psi,alpha)),ceil(ordCentro1+Ytot1(psi,alpha)*r/ maxforpix(psi,alpha)),ceil((altCentro1+Ztot1(psi,alpha)*r/ maxforpix(psi,alpha)-z)+z));
                    valy1(r,2)=Csub2(ceil(absCentro1+Xtot1(psi,alpha)*r/ maxforpix(psi,alpha)),ceil(ordCentro1+Ytot1(psi,alpha)*r/ maxforpix(psi,alpha)),ceil((altCentro1+Ztot1(psi,alpha)*r/ maxforpix(psi,alpha)-z)+z));
                end
            end
            valy1(:,3)=max(valy1(:,1),valy1(:,2));
            valr1(:,3)=max(valr1(:,1),valr1(:,2));
            y01(psi,alpha)=(trapz(valy1(:,4),(min(max(-1,(valy1(:,3)-1)/MTstab)+1,valr1(:,3)))))^(1/3);            % MT length corrected by yolk. Simple sum of [yolk] (<1) along MT (in ^3 evolution).

            if isempty(find(valr1==0,1))
                r01(psi,alpha)=size(valr1,1);           % MT length not corrected by yolk
            else r01(psi,alpha)=max(find(valr1(:,1)==0,1),find(valr1(:,2)==0,1));
            end

            if pullfactor >0 || pullfactor_exp >0
                valpol1=zeros(r01(psi,alpha)+2,1);     % polarity factor calculation
                for r=1:r01(psi,alpha)+2        % polarity not seen if further than 2 pixels away from the cell
                    if floor(absCentro1+Xtot1(psi,alpha)*r/ maxforpix(psi,alpha))>0 && floor(absCentro1+Xtot1(psi,alpha)*r/ maxforpix(psi,alpha))<=size(Bsub,1) && floor(ordCentro1+Ytot1(psi,alpha)*r/ maxforpix(psi,alpha))>0 && floor(ordCentro1+Ytot1(psi,alpha)*r/ maxforpix(psi,alpha))<=size(Bsub,2) && floor((altCentro1+Ztot1(psi,alpha)*r/ maxforpix(psi,alpha)-z)+z)>0 && floor((altCentro1+Ztot1(psi,alpha)*r/ maxforpix(psi,alpha)-z)+z)<=size(Bsub,3)
                        valpol1(r,1)=Bsub(floor(absCentro1+Xtot1(psi,alpha)*r/ maxforpix(psi,alpha)),floor(ordCentro1+Ytot1(psi,alpha)*r/ maxforpix(psi,alpha)),floor((altCentro1+Ztot1(psi,alpha)*r/ maxforpix(psi,alpha)-z)+z));
                    else valpol1(r,1)=0;
                    end
                end
                p01(psi,alpha)=max(valpol1);        % polarity seen by a MT = the maximum polarity intensity encountered along the MT
            else p01(psi,alpha)=0;
            end
            
            % same for 2nd aster
            valr2=zeros(ceil(-minforpix(psi,alpha)),2);
            valy2=zeros(ceil(-minforpix(psi,alpha)),4);
            r=1:-minforpix(psi,alpha);
            bornes=[find(ceil(absCentro2-Xtot2(psi,alpha)*r/minforpix(psi,alpha))>size(Asub,1),1),find(ceil(ordCentro2-Ytot2(psi,alpha)*r/minforpix(psi,alpha))>size(Asub,2),1),find(ceil((altCentro2-Ztot2(psi,alpha)*r/minforpix(psi,alpha)-z)+z)>size(Asub,3),1),find(ceil(absCentro2-Xtot2(psi,alpha)*r/minforpix(psi,alpha))<1,1),find(ceil(ordCentro2-Ytot2(psi,alpha)*r/minforpix(psi,alpha))<1,1),find(ceil((altCentro2-Ztot2(psi,alpha)*r/minforpix(psi,alpha)-z)+z)<1,1)];
            valy2(:,4)=((1:ceil(-minforpix(psi,alpha))).^3)';
            for r=1:min(-minforpix(psi,alpha),min(bornes)-1);
                valr2(r,1)=Asub(ceil(absCentro2-Xtot2(psi,alpha)*r/minforpix(psi,alpha)),ceil(ordCentro2-Ytot2(psi,alpha)*r/minforpix(psi,alpha)),ceil((altCentro2-Ztot2(psi,alpha)*r/minforpix(psi,alpha)-z)+z));
                valy2(r,1)=Csub2(ceil(absCentro2-Xtot2(psi,alpha)*r/minforpix(psi,alpha)),ceil(ordCentro2-Ytot2(psi,alpha)*r/minforpix(psi,alpha)),ceil((altCentro2-Ztot2(psi,alpha)*r/minforpix(psi,alpha)-z)+z));
                if size(Asub,1)>=floor(absCentro2-Xtot2(psi,alpha)*r/minforpix(psi,alpha)) && floor(absCentro2-Xtot2(psi,alpha)*r/minforpix(psi,alpha))>0 && size(Asub,2)>=floor(ordCentro2-Ytot2(psi,alpha)*r/minforpix(psi,alpha)) && floor(ordCentro2-Ytot2(psi,alpha)*r/minforpix(psi,alpha))>0 && size(Asub,3)>=floor((altCentro2-Ztot2(psi,alpha)*r/minforpix(psi,alpha)-z)+z) &&floor((altCentro2-Ztot2(psi,alpha)*r/minforpix(psi,alpha)-z)+z)>0
                    valr2(r,2)=Asub(floor(absCentro2-Xtot2(psi,alpha)*r/minforpix(psi,alpha)),floor(ordCentro2-Ytot2(psi,alpha)*r/minforpix(psi,alpha)),floor((altCentro2-Ztot2(psi,alpha)*r/minforpix(psi,alpha)-z)+z));
                    valy2(r,2)=Csub2(floor(absCentro2-Xtot2(psi,alpha)*r/minforpix(psi,alpha)),floor(ordCentro2-Ytot2(psi,alpha)*r/minforpix(psi,alpha)),floor((altCentro2-Ztot2(psi,alpha)*r/minforpix(psi,alpha)-z)+z));
                end
            end
            valy2(:,3)=max(valy2(:,1),valy2(:,2));
            valr2(:,3)=max(valr2(:,1),valr2(:,2));
            y02(psi,alpha)=(trapz(valy2(:,4),(min(max(-1,(valy2(:,3)-1)/MTstab)+1,valr2(:,3)))))^(1/3);

            if isempty(find(valr2==0,1))
                r02(psi,alpha)=size(valr2,1);
            else r02(psi,alpha)=max(find(valr2(:,1)==0,1),find(valr2(:,2)==0,1));
            end
            
            if pullfactor >0 || pullfactor_exp >0
                valpol2=zeros(r02(psi,alpha)+2,1);
                for r=1:r02(psi,alpha)+2
                    if ceil(absCentro2-Xtot2(psi,alpha)*r/minforpix(psi,alpha))>0 && ceil(absCentro2-Xtot2(psi,alpha)*r/minforpix(psi,alpha))<=size(Bsub,1) && ceil(ordCentro2-Ytot2(psi,alpha)*r/minforpix(psi,alpha))>0 && ceil(ordCentro2-Ytot2(psi,alpha)*r/minforpix(psi,alpha))<=size(Bsub,2) && ceil((altCentro2-Ztot2(psi,alpha)*r/minforpix(psi,alpha)-z)+z)>0 && ceil((altCentro2-Ztot2(psi,alpha)*r/minforpix(psi,alpha)-z)+z)<=size(Bsub,3)
                        valpol2(r,1)=Bsub(ceil(absCentro2-Xtot2(psi,alpha)*r/minforpix(psi,alpha)),ceil(ordCentro2-Ytot2(psi,alpha)*r/minforpix(psi,alpha)),ceil((altCentro2-Ztot2(psi,alpha)*r/minforpix(psi,alpha)-z)+z));
                    else valpol2(r,1)=0;
                    end
                end
                p02(psi,alpha)=max(valpol2);
            else p02(psi,alpha)=0;
            end
            
        end
    end

    % out of the aster angular extent, MTs length and polarity = 0
    for alpha=floor(anglelimit*180)+1:179
        for psi=1:360
            y01(psi,alpha)=0;
            p01(psi,alpha)=0;
            y02(psi,alpha)=0;
            p02(psi,alpha)=0;
        end
    end


    %% Final length matrices

    length1=sqrt((Xtot1.*y01./maxforpix).^2+(Ytot1.*y01./maxforpix).^2+(Ztot1.*y01./maxforpix).^2)/caract_length;
    length2=sqrt((-Xtot2.*y02./minforpix).^2+(-Ytot2.*y02./minforpix).^2+(-Ztot2.*y02./minforpix).^2)/caract_length;


    %% Total polarity seen by the asters
    
    p01_smooth=p01;     % angular polarity matrix for aster 1
    p02_smooth=p02;     % angular polarity matrix for aster 2

    if pullfactor >0 || pullfactor_exp >0

        % Low-range smoothing to bring to non-zero pixel-related holes in the polarity seen by the asters
        for alpha=1:floor(anglelimit*180)
            p011=smooth(p01_smooth(1:size(p01,1),alpha),20,'lowess');
            p01_smooth(1:size(p01,1),alpha)=p011;
        end
        for psi=1:360
            p011=smooth(p01_smooth(psi,1:size(p01,2)),5,'lowess');
            p01_smooth(psi,1:size(p01,2))=p011;
        end
        for alpha=1:floor(anglelimit*180)
            p021=smooth(p02_smooth(1:size(p02,1),alpha),20,'lowess');
            p02_smooth(1:size(p02,1),alpha)=p021;
        end
        for psi=1:360
            p021=smooth(p02_smooth(psi,1:size(p02,2)),5,'lowess');
            p02_smooth(psi,1:size(p02,2))=p021;
        end

        % labelling of the smoothed matrices, to define the cap vs not cap zones
        p01_lab1=bwlabel(p01_smooth);
        p02_lab1=bwlabel(p02_smooth);
        p01_lab2=p01_lab1;
        p02_lab2=p02_lab1;
        p01_lab2(p01_lab1>=1)=0;
        p01_lab2(p01_lab1==0)=1;
        p02_lab2(p02_lab1>=1)=0;
        p02_lab2(p02_lab1==0)=1;
        p01_lab3=bwlabel(p01_lab2);
        p02_lab3=bwlabel(p02_lab2);

        % for aster 1...
        Rprcell1=regionprops(p01_lab3,'Area');
        Rpr1=NaN(length(Rprcell1),1);
        if isempty(Rpr1)
        else
            for i=1:length(Rpr1)
                Rpr1(i)=Rprcell1(i,1).Area;
            end
            [maxRpr1 labelmax1]=max(Rpr1);
            [alab blab]=find(p01_lab3(360,:)==labelmax1);
            if find(labelmax1==0)
                labelmax1=setxor(unique([labelmax1 p01_lab3(1,blab)]),0);
            else labelmax1=unique(labelmax1);
            end
            for i=1:length(labelmax1)
                [alab blab]=find(p01_lab3(1,:)==labelmax1(i));
                labelmax1=[labelmax1 p01_lab3(360,blab)]; %#ok<AGROW>
            end
            if find(labelmax1==0)
                labelmax1=setxor(unique(labelmax1),0);
            else labelmax1=unique(labelmax1);
            end
            for i=1:length(labelmax1)
                [alab blab]=find(p01_lab3(360,:)==labelmax1(i));
                labelmax1=[labelmax1 p01_lab3(1,blab)]; %#ok<AGROW>
            end
            if find(labelmax1==0)
                labelmax1=setxor(unique(labelmax1),0);
            else labelmax1=unique(labelmax1);
            end
            p01_lab=ones(size(p01_lab3,1),size(p01_lab3,2));
            for i=1:length(labelmax1)
                if labelmax1(i)==0
                else
                    p01_lab(p01_lab3==labelmax1(i))=0;    % Matrix of 1 cap and 0 not cap
                end
            end
        end

        % same for aster 2...
        Rprcell2=regionprops(p02_lab3,'Area');
        Rpr2=NaN(length(Rprcell2),1);
        if isempty(Rpr2)
        else
            for i=1:length(Rpr2)
                Rpr2(i)=Rprcell2(i,1).Area;
            end
            [maxRpr2 labelmax2]=max(Rpr2);
            [alab blab]=find(p02_lab3(360,:)==labelmax2);
            if find(labelmax2==0)
                labelmax2=setxor(unique([labelmax2 p02_lab3(1,blab)]),0);
            else labelmax2=unique(labelmax2);
            end
            for i=1:length(labelmax2)
                [alab blab]=find(p02_lab3(1,:)==labelmax2(i));
                labelmax2=[labelmax2 p02_lab3(360,blab)]; %#ok<AGROW>
            end
            if find(labelmax2==0)
                labelmax2=setxor(unique(labelmax2),0);
            else labelmax2=unique(labelmax2);
            end
            for i=1:length(labelmax2)
                [alab blab]=find(p02_lab3(360,:)==labelmax2(i));
                labelmax2=[labelmax2 p02_lab3(1,blab)]; %#ok<AGROW>
            end
            if find(labelmax2==0)
                labelmax2=setxor(unique(labelmax2),0);
            else labelmax2=unique(labelmax2);
            end
            p02_lab=ones(size(p02_lab3,1),size(p02_lab3,2));
            for i=1:length(labelmax2)
                if labelmax2(i)==0
                else
                    p02_lab(p02_lab3==labelmax2(i))=0;
                end
            end
        end

        % initialisation of next smoothing step
        Ulab1=unique(p01_lab3);
        Ulab2=unique(p02_lab3);
        Xor1=setxor(Ulab1, labelmax1);
        if find(Xor1==0)
            Xor1=setxor(Xor1,0);
        end
        Xor2=setxor(Ulab2, labelmax2);
        if find(Xor2==0)
            Xor2=setxor(Xor2,0);
        end
        for i=1:length(Xor1)
            p01_smooth(p01_lab3==Xor1(i))=max(max(p01));
        end
        for i=1:length(Xor2)
            p02_smooth(p02_lab3==Xor2(i))=max(max(p02));
        end

        % Smoothing to bring the holes to the neighbor intensity values, without changing the neighbors
        for smoothi=1:10
            for alpha=1:floor(anglelimit*180)   % smoothing...
                p011=smooth(p01_smooth(1:size(p01,1),alpha),5*(11-smoothi),'lowess');
                p01_smooth(1:size(p01,1),alpha)=p011;
            end
            for psi=1:360
                p011=smooth(p01_smooth(psi,1:size(p01,2)),1*(11-smoothi),'lowess');
                p01_smooth(psi,1:size(p01,2))=p011;
            end
            for alpha=1:floor(anglelimit*180)
                p021=smooth(p02_smooth(1:size(p02,1),alpha),5*(11-smoothi),'lowess');
                p02_smooth(1:size(p02,1),alpha)=p021;
            end
            for psi=1:360
                p021=smooth(p02_smooth(psi,1:size(p02,2)),1*(11-smoothi),'lowess');
                p02_smooth(psi,1:size(p02,2))=p021;
            end
            p01_smooth(p01_lab==0)=0;   % resetting the neighbors...
            p02_smooth(p02_lab==0)=0;
            p01_smooth(p01>0)=p01(p01>0);
            p02_smooth(p02>0)=p02(p02>0);
            if smoothi<8        % to get faster
                for i=1:size(Xor1,2)
                    p01_smooth(p01_lab3==Xor1(i))=max(max(p01));
                end
                for i=1:size(Xor2,2)
                    p02_smooth(p02_lab3==Xor2(i))=max(max(p02));
                end
            end
        end
    end


    %% Net force and torque calculation

    length1unit=length1./Unit_branch_2;
    length2unit=length2./Unit_branch_2;
    
    
    % Torque (along theta and phi) and force (along x, y, z relative to the spindle orientation) per MT, for asters 1 and 2
    torqueperMT1(:,:,1)=densMT*pi/180*(abs(cos(Alphamat)-cos(Alphamat-pi/(180)))).*sin(Alphamat).*(length1.^(Beta1)+ (length1.^(Beta2)).*(min(p01_smooth.*mult_int,100))/100.*pullfactor + ceil((min(p01_smooth,1))-seuil_pol).*pullfactor_exp.*(2.^(length1unit))).*sin(Psimat);
    torqueperMT2(:,:,1)=densMT*pi/180*(abs(cos(Alphamat)-cos(Alphamat-pi/(180)))).*sin(Alphamat).*(length2.^(Beta1)+ (length2.^(Beta2)).*(min(p02_smooth.*mult_int,100))/100.*pullfactor + ceil((min(p02_smooth,1))-seuil_pol).*pullfactor_exp.*(2.^(length2unit))).*sin(Psimat);
    torqueperMT1(:,:,2)=-densMT*pi/180*(abs(cos(Alphamat)-cos(Alphamat-pi/(180)))).*sin(Alphamat).*(length1.^(Beta1)+ (length1.^(Beta2)).*(min(p01_smooth.*mult_int,100))/100.*pullfactor + ceil((min(p01_smooth,1))-seuil_pol).*pullfactor_exp.*(2.^(length1unit))).*cos(Psimat);
    torqueperMT2(:,:,2)=-densMT*pi/180*(abs(cos(Alphamat)-cos(Alphamat-pi/(180)))).*sin(Alphamat).*(length2.^(Beta1)+ (length2.^(Beta2)).*(min(p02_smooth.*mult_int,100))/100.*pullfactor + ceil((min(p02_smooth,1))-seuil_pol).*pullfactor_exp.*(2.^(length2unit))).*cos(Psimat);
    forceperMT1z(:,:)=densMT*pi/180*(abs(cos(Alphamat)-cos(Alphamat-pi/(180)))).*cos(Alphamat).*(length1.^(Beta1)+ (length1.^(Beta2)).*(min(p01_smooth.*mult_int,100))/100.*pullfactor + ceil((min(p01_smooth,1))-seuil_pol).*pullfactor_exp.*(2.^(length1unit)));
    forceperMT2z(:,:)=-densMT*pi/180*(abs(cos(Alphamat)-cos(Alphamat-pi/(180)))).*cos(Alphamat).*(length2.^(Beta1)+ (length2.^(Beta2)).*(min(p02_smooth.*mult_int,100))/100.*pullfactor + ceil((min(p02_smooth,1))-seuil_pol).*pullfactor_exp.*(2.^(length2unit)));
    forceperMT1x(:,:)=densMT*pi/180*(abs(cos(Alphamat)-cos(Alphamat-pi/(180)))).*sin(Alphamat).*cos(Psimat).*(length1.^(Beta1)+ (length1.^(Beta2)).*(min(p01_smooth.*mult_int,100))/100.*pullfactor + ceil((min(p01_smooth,1))-seuil_pol).*pullfactor_exp.*(2.^(length1unit)));
    forceperMT2x(:,:)=-densMT*pi/180*(abs(cos(Alphamat)-cos(Alphamat-pi/(180)))).*sin(Alphamat).*cos(Psimat).*(length2.^(Beta1)+ (length2.^(Beta2)).*(min(p02_smooth.*mult_int,100))/100.*pullfactor + ceil((min(p02_smooth,1))-seuil_pol).*pullfactor_exp.*(2.^(length2unit)));
    forceperMT1y(:,:)=densMT*pi/180*(abs(cos(Alphamat)-cos(Alphamat-pi/(180)))).*sin(Alphamat).*sin(Psimat).*(length1.^(Beta1)+ (length1.^(Beta2)).*(min(p01_smooth.*mult_int,100))/100.*pullfactor + ceil((min(p01_smooth,1))-seuil_pol).*pullfactor_exp.*(2.^(length1unit)));
    forceperMT2y(:,:)=-densMT*pi/180*(abs(cos(Alphamat)-cos(Alphamat-pi/(180)))).*sin(Alphamat).*sin(Psimat).*(length2.^(Beta1)+ (length2.^(Beta2)).*(min(p02_smooth.*mult_int,100))/100.*pullfactor + ceil((min(p02_smooth,1))-seuil_pol).*pullfactor_exp.*(2.^(length2unit)));

    
    % Net torque (along theta and phi) and force (along x, y, z)
    Potentiel(it,1)=(sum(sum(torqueperMT1(:,1:floor(anglelimit*180),1)))+sum(sum(torqueperMT2(:,1:floor(anglelimit*180),1))));
    Potentiel(it,2)=(sum(sum(torqueperMT1(:,1:floor(anglelimit*180),2)))+sum(sum(torqueperMT2(:,1:floor(anglelimit*180),2))));
    pot3=sum(sum(forceperMT1x(:,1:floor(anglelimit*180))))+sum(sum(forceperMT2x(:,1:floor(anglelimit*180))));
    pot4=sum(sum(forceperMT1y(:,1:floor(anglelimit*180))))+sum(sum(forceperMT2y(:,1:floor(anglelimit*180))));
    pot5=sum(sum(forceperMT1z(:,1:floor(anglelimit*180))))+sum(sum(forceperMT2z(:,1:floor(anglelimit*180))));
    Potentiel(it,3)=(pot5*sin(thetarad)*cos(phirad)-pot4*sin(phirad)+pot3*cos(thetarad)*cos(phirad));
    Potentiel(it,4)=(pot5*sin(thetarad)*sin(phirad)+pot4*cos(phirad)+pot3*cos(thetarad)*sin(phirad));
    Potentiel(it,5)=pot5*cos(thetarad)-pot3*sin(thetarad);
    pottempa=Potentiel(it,:);       % net torque and force matrix

else
    [ifexist indice]=ismember([x,y,z,theta,phi],CoordsPotentiel,'rows');
    pottempa=Potentiel(indice,:);
end

