% Surfave_Evolver_to_Matlab_11
% Created 02/12/2014
% Program that converts a surface evolver surface to a matlab matrix.

% Inputs, all avalaible by copy-paste of the text output file of surface evolver (save command in surface evolver : d) :
%    u1 : table of facets numbers of the considered cell in the surface evolver output. Beware of taking just one of the cells. Size and doublons don't matter, just has to be rectangular.
%    u2 : table of edges (col. 2, 3, 4) for every facet of the file (col. 1).
%    u3 : table of vertices (col. 2, 3) for every edge of the file (col. 1).
%    u4 : table of vertices coordinates (col. 2, 3, 4) for every vertex of the file (col. 1).

% Outputs :
%    .tif images of a Z-stack of the surface. Black background and white vertices (if mesh is narrow enough, vertices -> surface). Should be inverted and filled in ImageJ.
%    save of workspace




close all
clear all


%% Parameters

% Path ([Rpath1 Rpath2]) and name (filename) of the input file containing u1, u2, u3, u4.
Rpath1='C:\Users\Analle\Desktop\Surf Evolver\';
Rpath2='Urchin_tetra_diff';
filename='matlabsurfprec_c1';    % The workspace will be saved in the same location, under the same name '_final'.

% Where the output images will be saved
Rawpath=[Rpath1 Rpath2 '\im1'];
digits=4;

Confinement_coeff=0.27;  % The confinement coefficient of surface evolver (R in paper)

Output_size=160; % Size in pix of the output Asub


%% Program

load([Rpath1 Rpath2 '\' filename])
pause(3);

Confinement_coeff=sqrt(Confinement_coeff*sqrt(3));
digits_format =['%0' num2str(digits) 'd'];

disp(['Running surf_ev_to_matlab... Outputs will be saved in ' Rawpath '.']);

u1=abs(u1);
u2=abs(u2);

% Selecting only the edges corresponding to the input facets (ie the edges of the selected cell)
disp('Computing faces...');
pause(0.1);
faces1=zeros(size(u1,1)*size(u1,2),4);
nn=0;
for n=1:size(u1,1)
    for m=1:size(u1,2)
        nn=nn+1;
        faces1(nn,:)=u2(u2(:,1)==u1(n,m),:);
    end
end
edges=faces1(:,2:4);
clear faces1

% Selecting only the vertices corresponding to these edges (ie the vertices of the selected cell)
disp('Computing edges...');
pause(0.1);
edges1=zeros(size(edges,1)*size(edges,2),3);
nn=0;
for n=1:size(edges,1)
    for m=1:size(edges,2)
        nn=nn+1;
        edges1(nn,:)=u3(u3(:,1)==edges(n,m),:);
    end
end
vertices=edges1(:,2:3);
clear edges1

% Selecting only the coordinates corresponding to these vertices (ie the coordinates of the selected cell)
disp('Computing vertices...');
pause(0.1);
vertices1=zeros(size(vertices,1)*size(vertices,2),4);
nn=0;
for n=1:size(vertices,1)
    for m=1:size(vertices,2)
        nn=nn+1;
        vertices1(nn,:)=u4(u4(:,1)==vertices(n,m),:);
    end
end
coords=vertices1(:,2:4);
clear vertices1

% Rescaling the vertices coordinates to the requested output matrix size
coords2=coords*(floor(77/80*Output_size/2))/Confinement_coeff+Output_size/2;

% Creating Asub, the output 3D matrix (saved as images Z-stack)
disp('Creating output matrix...');
pause(0.1);
Asub=zeros(Output_size,Output_size,Output_size);

for n=1:size(coords2,1)
    Asub(floor(coords2(n,1)),floor(coords2(n,2)),floor(coords2(n,3)))=1;
end

% Check plot of the output surface
d=figure;
p1 = patch(isosurface(Asub,0.5), 'FaceColor','blue','EdgeColor','none','EdgeAlpha',0.5,'FaceAlpha',0.15);
axis equal

% Saving as Z-stack (separate images)
disp(['Saving in ' Rawpath '...']);
pause(0.1);
for n=1:size(Asub,3)
    imwrite(Asub(:,:,n), [Rawpath '\3D_Shape' num2str(n,digits_format)],'tif');
end

close all
pause(2)

% Saving workspace
save([Rpath1 Rpath2 '\' filename '_final.mat'])
pause(1)

disp('Done.');



